@@ -13,6 +13,7 @@ from dataclasses import dataclass
 from io import BytesIO
 from typing import Optional
 
+import yarl
 from aiohttp import FormData
 from http_tools import AbmServiceConnector
 from http_tools.mime_types import ContentType
@@ -76,19 +77,25 @@ class FileServerConnector:
     Context = AbmServiceConnector.Context
 
     def __init__(self, config: Config, context: Context):
+        self.config = config
         self._connector = AbmServiceConnector(config, context)
 
+    def get_file_url(self, file_id: str) -> yarl.URL:
+        return (yarl.URL(self.config.url) / 'file/get').with_query({'id': file_id})
+
     async def get_file(self, file_id: str, range_: Optional[str] = None) -> bytes:
         args = {"id": file_id}
         headers = self._construct_headers()
         if range_ is not None:
             headers["Range"] = range_
-        return await self._connector.get("/file/get", args, headers=headers)
+        content = await self._connector.get("/file/get", args, headers=headers)
+        assert isinstance(content, bytes)
+        return content
 
-    async def get_file_info(self, file_id: str) -> FileLink:
+    async def get_file_info(self, file_id: str) -> FileLink | None:
         args = {"id": file_id}
-        answer = await self._connector.get("/file/info", args, headers=self._construct_headers())
-        return dict_to_dataclass(answer, FileLink)
+        if answer := await self._connector.get("/file/info", args, headers=self._construct_headers()):
+            return dict_to_dataclass(answer, FileLink)
 
     async def get_thumbnail(self, file_id: str) -> bytes:
         return await self._connector.get("file/preview", {"id": file_id}, headers=self._construct_headers())
@@ -109,9 +116,9 @@ class FileServerConnector:
             thumbnail = dict_to_dataclass(thumbnail, FileLink)
         return original, thumbnail
 
-    async def upload_from(self, file_url: str) -> FileLink:
+    async def upload_from(self, file_url: str | yarl.URL) -> FileLink:
         answer = await self._connector.post(
-            "/file/add_from", payload={"file_url": file_url}, headers=self._construct_headers()
+            "/file/add_from", payload={"file_url": str(file_url)}, headers=self._construct_headers()
         )
         return dict_to_dataclass(answer, FileLink)
 
